Structs
- CallArg
- Expr
- Match
Arm - Param
- Program
- Top-level program: a list of statements.
- Select
Branch - A branch in a
select {}expression. - Span
- Represents a location in source for error reporting.
- Stmt
Enums
- Assign
Op - Assign
Target - BinOp
- Dict
Entry - A dict entry: either a key-value pair or a spread
...expr. - Enum
Pattern Fields - Expr
Kind - FStr
Part - List
Entry - A list entry: either a single element or a spread
...expr. - Pattern
- Stmt
Kind - TypeAnn
- Optional type annotation for
letbindings. Inner/generic types are parsed but only the outer type is checked at runtime (e.g.list<int>checks that the value is a list, not that elements are ints). - UnaryOp
- UseImports
- What to import from a module path.