Module module
ion_
core
0.2.1
Module module
Module Items
Structs
In crate ion_
core
ion_core
Module
module
Structs

Module
A named collection of functions and values that can be registered with an Engine and accessed via
module::name
syntax in Ion scripts.