pub struct Parser { /* private fields */ }Implementations
Sourceimpl Parser
impl Parser
pub fn new(tokens: Vec<SpannedToken>) -> Self
Sourcepub fn parse_program_recovering(&mut self) -> ParseOutput
pub fn parse_program_recovering(&mut self) -> ParseOutput
Parse the full program, recovering from errors at statement boundaries.
Returns a ParseOutput containing both the partial AST and any errors.
Sourcepub fn parse_program(&mut self) -> Result<Program, IonError>
pub fn parse_program(&mut self) -> Result<Program, IonError>
Parse the full program, returning an error if any parse errors occurred.
For multi-error reporting, use parse_program_recovering instead.