Module stdlib

Module stdlib 

Built-in standard library modules.

These modules are automatically registered in every Engine instance and provide namespaced access to common functions and constants. The same functions remain available as top-level builtins for backwards compatibility.

Structs

StdOutput
Output handler that writes to the process stdout/stderr streams.

Enums

OutputStream
Output stream requested by Ion’s io stdlib module.

Traits

OutputHandler
Host-side output handler for Ion’s io::print* functions.

Functions

io_module
Build the io stdlib module.
io_module_with_output
Build the io stdlib module with a host-provided output handler.
json_module
Build the json stdlib module.
math_module
Build the math stdlib module.
register_stdlib
Register all stdlib modules in the given environment.
register_stdlib_with_output
Register all stdlib modules with a host-provided output handler.
string_module
Build the str stdlib module.