Module ast

Module ast 

Structs

CallArg
Expr
MatchArm
Param
Program
Top-level program: a list of statements.
SelectBranch
A branch in a select {} expression.
Span
Represents a location in source for error reporting.
Stmt

Enums

AssignOp
AssignTarget
BinOp
DictEntry
A dict entry: either a key-value pair or a spread ...expr.
EnumPatternFields
ExprKind
FStrPart
ListEntry
A list entry: either a single element or a spread ...expr.
Pattern
StmtKind
TypeAnn
Optional type annotation for let bindings. Inner/generic types are parsed but only the outer type is checked at runtime (e.g. list<int> checks that the value is a list, not that elements are ints).
UnaryOp
UseImports
What to import from a module path.